<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="130px" >
        <el-form-item label="资源名称:" prop="name" >
          <el-input v-model.trim="state.form.name" placeholder="请输入资源名称"></el-input>
        </el-form-item>
        <el-form-item label="资源类型:" prop="resourceType" >
          <el-select
              @change="changeType"
              v-model="state.form.resourceType"
              placeholder="请选择资源类型"
              size="default"
              style="width: 100%"

          >
            <el-option
                v-for="item in state.typeList"
                :key="item.id"
                :label="item.name"
                :value="item.id"
            />
          </el-select>
        </el-form-item>
        <el-form-item  label="资源时长(秒)：" prop="resourceLength"  v-if="(state.form.resourceType == 1 || state.form.resourceType == 2)&& state.form.resourceLength">
          <el-input
              :disabled="state.form.resourceLength!=0"
              v-model="state.form.resourceLength"
              style="width: 100%"
              placeholder="请输入资源时长(秒)"
          >
            <template #append>秒</template>
          </el-input>
        </el-form-item>
        <el-form-item  label="文档页数：" prop="docPage"  v-if="state.form.resourceType == 3 && state.form.docPage ">
          <el-input
              :disabled="state.form.docPage!=0"
              v-model="state.form.docPage"
              style="width: 100%"
              placeholder="请输入文档页数："
          >
            <template #append>页</template>
          </el-input>
        </el-form-item>

        <el-form-item  label="资源上传：">
          <file-upload ref="fileRef" :responseType="state.form.resourceType" @getFile="getFile"></file-upload>
        </el-form-item>

      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {nextTick, reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany} from "@/api/onlineEducation/company";
import {verifyPhone} from "@/utils/validate";
import {addBanner, delPic, editBanner, getBannerById} from "@/api/onlineEducation/banner";
import {getToken} from "@/utils/auth";
import {getUserById} from "@/api/onlineEducation/user";
import {addResource, checkResourceName, editResource, getResourceById} from "@/api/onlineEducation/courseResource";
import fileUpload from '@/views/components/upload.vue'
import Cookies from "js-cookie";

const dialogVisible = ref(false);
const title = ref("");
const fileRef = ref();
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startUsername = ref('');
const startPhone = ref('');

const validateName = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入资源名称'))
  }else if(title.value === '资源编辑' && value === startUsername.value){
    callback()
  }else{
    let param = {}
    if(title.value === '资源新增') {
      param = {
        name:value,
      }
    }else if(title.value === '资源编辑'){
      param = {
        name:value,
        id: state.form.id
      }
    }
    checkResourceName(param).then((res)=>{
      if(res.data == false){
        callback(new Error('资源名称已被占用，请更换其他名称'))
      }else{
        callback()
      }
    })
  }
}

const state = reactive({
  form: {
    id: '',
    name: '',
    mediaType: '',
    resourceType: null,
    companyId: null,
    resourcePath:'',
    md5: '',
    resourceSize: null,
    resourceLength: '',
    docPage: null,
    originName: ''
  },
  formRules:{
    name: [{ required: true, trigger: "blur", validator: validateName }],
    resourceType:[{ required: true, message: '请选择资源类型', trigger: 'blur' }],
    resourceLength: [{ required: true, trigger: "blur", message: '请输入资源时长(秒)' }],
  },
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization:getToken()
  },
  imgLimit: 1,
  imgList: [],
  typeList: [
    {
      id: 1,
      name: '视频'
    },
    {
      id: 2,
      name: '音频'
    },
    {
      id: 3,
      name: '文档'
    },
  ]
})
const  handleChange = (file, fileLists) => {
  state.form.file = file.raw;
  console.log(file);
  // 这里把数组置空是为了每次只能上传一个文件,以防报错
  state.imgList = [];
  state.form.mediaType = file.raw.type
}
const handleAvatarSuccess = (response, file, fileList) => {
  if(response.code == 200){
    if(file && file.raw){
      state.form.mediaType = file.raw.type
    }
    state.form.file = file
  }else{
    state.imgList = []
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}
const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}
const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 5){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过5M'
    });
    return false
  }
};
const handleRemove = async (file, uploadFiles) => {
  let path = state.form.imgUrl;
  await delPic({path: path}).then(res => {
    if(res.code == 200){
      // ElMessage({
      //   type: 'success',
      //   message: '文件已删除'
      // })
      state.form.imgUrl = ''
    }else{
      ElMessage({
        type: 'warning',
        message: res.message
      })
    }
  }).catch(() => {
    state.form.imgUrl = ''
  });
}

const openDialog = async (type, value) => {
  length.value = value.listLength
  title.value = type === 'add' ? '资源新增' : type ==='edit' ? '资源编辑' : '' ;
  if(type === 'edit') {
    const res = await getResourceById(value.id);
    if(res.code === 200){
      state.form = res.data
    }else{
      ElMessage.warning(res.message)
    }
  }
  dialogVisible.value = true;
  if(type === 'edit') {
    await nextTick(() => {
      fileRef.value.open(state.form);
    })
  }
}
const getFile = (val) => {

  if(val.md5 != ''){
    state.form.md5 = val.md5
    state.form.resourcePath = val.resourcePath
    state.form.mediaType = val.mediaType
    state.form.resourceSize = val.resourceSize
    state.form.docPage = val.docPage
    state.form.resourceLength = val.resourceLength
    state.form.originName = val.originName
  } else if( val.md5 == ''){
    state.form.resourceType = ''

  } else {
      ElMessage({
        type: 'warning',
        message: '请上传题库资源'
      });
  }
}

const changeType = (val) => {
  state.form.md5 = ''
  state.form.resourcePath = ''
  state.form.mediaType =''
  state.form.resourceSize = null
  state.form.docPage = null
  state.form.resourceLength = null
  state.form.originName = ''
  fileRef.value.changeType(val);
}
const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '资源新增'){
      const {id,...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addResource(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      dialogVisible.value = false;
      emit("getList")
      busRef.value.clearValidate();
      fileRef.value.dispose();
      reset();


    }else if(title.value === '资源编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editResource(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      dialogVisible.value = false;
      emit("getList")
      busRef.value.clearValidate();
      fileRef.value.dispose();
      reset();


    }
  }
}

const handleClose = () => {
  dialogVisible.value = false;
  fileRef.value.dispose();
  busRef.value.clearValidate();
  reset();

  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    name: '',
    mediaType: '',
    resourceType: null,
    companyId: null,
    resourcePath:'',
    md5: '',
    resourceSize: null,
    resourceLength: '',
    docPage: null,
    originName: ''
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
